@@ -625,6 +625,7 @@ class XArrayInterface(GridInterface):
             coords[k] = (k, v)
         if coords:
             data = data.assign_coords(**coords)
+
         dims = tuple(kd.name for kd in dataset.kdims[::-1])
         vars = OrderedDict()
         for k, v in new_data.items():
@@ -634,11 +635,16 @@ class XArrayInterface(GridInterface):
                 vars[k] = v
             else:
                 vars[k] = (dims, cls.canonicalize(dataset, v, data_coords=dims))
-        if vars:
-            data = data.assign(vars)
-        used_coords = set.intersection(*[set(var.coords) for var in data.data_vars.values()])
-        drop_coords = set.symmetric_difference(used_coords, prev_coords)
-        return data.drop(list(drop_coords)), list(drop_coords)
+
+        if len(vars) == 1 and list(vars) == [vd.name for vd in dataset.vdims]:
+            data = vars[dataset.vdims[0].name]
+            used_coords = set(data.coords)
+        else:
+            if vars:
+                data = data.assign(vars)
+            used_coords = set.intersection(*[set(var.coords) for var in data.data_vars.values()])
+        drop_coords =  set.symmetric_difference(used_coords, prev_coords)
+        return data.drop([c for c in drop_coords if c in data.coords]), list(drop_coords)
 
 
 Interface.register(XArrayInterface)
